﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace XamDataChart
{
    public class BorrowModel : ICloneable, INotifyPropertyChanged
    {
     public BorrowModel()
        {
        }

       private double _interval;
       public double Interval
        {
            get { return this._interval; }

            set
            {
                this._interval = value;
                this.NotifyPropertyChanged("Period");
                this.NotifyPropertyChanged("Interval");
                this.NotifyPropertyChanged("BorrowRate");
                this.NotifyPropertyChanged("PeriodValue");
                this.NotifyPropertyChanged("IntervalUnit");
            }

        }

       private double _periodValue;
       public double PeriodValue
       {
           get { return this._periodValue; }

           set
           {
               this._periodValue = value;
               IntervalValuePeriod();
               this.NotifyPropertyChanged("Period");
               this.NotifyPropertyChanged("Interval");
               this.NotifyPropertyChanged("BorrowRate");
               this.NotifyPropertyChanged("PeriodValue");
               this.NotifyPropertyChanged("IntervalUnit");
           }

       }

     
      
       private Period _period;

        public Period Period
       {
           get { return this._period; }
           set
           {
               this._period = value;
               PeriodValueToInterval();
               this.NotifyPropertyChanged("Period");
               this.NotifyPropertyChanged("Interval");
               this.NotifyPropertyChanged("BorrowRate");
               this.NotifyPropertyChanged("PeriodValue");
               this.NotifyPropertyChanged("IntervalUnit");
           }
       }

       private string _intervalUnit = "Month";

       public string IntervalUnit
       {
           get { return this._intervalUnit; }
           set
           {
               this._intervalUnit = value;
               IntervalValuePeriod();
               this.NotifyPropertyChanged("Period");
               this.NotifyPropertyChanged("Interval");
               this.NotifyPropertyChanged("BorrowRate");
               this.NotifyPropertyChanged("PeriodValue");
               this.NotifyPropertyChanged("IntervalUnit");
           }
       }

       private decimal _borrowRate;

        public decimal BorrowRate
        {
            get { return this._borrowRate; }
            set
            {
                this._borrowRate = value;
                this.NotifyPropertyChanged("Period");
                this.NotifyPropertyChanged("Interval");
                this.NotifyPropertyChanged("BorrowRate");
                this.NotifyPropertyChanged("PeriodValue");
                this.NotifyPropertyChanged("IntervalUnit");
            }
        }

        public object Clone()
        {
            return this.MemberwiseClone();
        }

        private void PeriodValueToInterval()
        {
            _periodValue = _period.Duration;
           switch (_period.Unit)
           {

               case TimeUnit.Month:
                  
                   Interval = _period.Duration * 30;
                 
                     break;

               case TimeUnit.Year:

                     Interval = _periodValue * 360;

                     break;

               case TimeUnit.Day:
                     Interval = _periodValue * 1;
                     break;

        }
          
       }

        private void IntervalValuePeriod()
        {
            _period.Duration = _periodValue;
            if (!string.IsNullOrWhiteSpace(_intervalUnit))
            {
                switch (_intervalUnit)
                {
                    case "Month":

                        Interval = _periodValue * 30;
                        _period.Unit = TimeUnit.Month;
                        break;

                    case "Year":

                        Interval = _periodValue * 360;
                        _period.Unit = TimeUnit.Year;
                        break;

                    case "Day":
                        Interval = _periodValue * 1;
                      
                        _period.Unit = TimeUnit.Day;
                        break;

                }
            }
          
        }
       #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
    }
}
